==> jc-1.4.0.tar.gz: soot/toolkits/scalar/ForwardBranchedFlowAnalysis.h <==
// public abstract class soot.toolkits.scalar.ForwardBranchedFlowAnalysis

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 36c7c662bc399f02 soot_toolkits_scalar_AbstractFlowAnalysis
// @dep_class 6279fcb5fd9bedca soot_toolkits_scalar_BranchedFlowAnalysis
// @dep_class 1296f6ac3f04ebc9 soot_toolkits_scalar_ForwardBranchedFlowAnalysis

// header file dependencies
// @dep_header soot_toolkits_scalar_BranchedFlowAnalysis

#include "soot/toolkits/scalar/BranchedFlowAnalysis.h"

#ifndef _JC_soot_toolkits_scalar_ForwardBranchedFlowAnalysis_H_
#define _JC_soot_toolkits_scalar_ForwardBranchedFlowAnalysis_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_soot_Unit$object;
struct _jc_soot_toolkits_graph_UnitGraph$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$sub_refs	_jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$sub_refs;
typedef struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$sub_nonrefs	_jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$refs	_jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$refs;
typedef struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$nonrefs	_jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$nonrefs;
typedef struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$object	_jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$object;

typedef const struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$vmethods	_jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$vmethods;
typedef const struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$vtable	_jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$vtable;
typedef const struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$vtype	_jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$method$_init$4a1d314cee6c2507(_jc_env *, struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$object *, struct _jc_soot_toolkits_graph_UnitGraph$object *);

// Virtual methods
extern void _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$method$accumulateAfterFlowSets$d719cbc2c96a3105(_jc_env *, struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$object *, struct _jc_object *, struct _jc_object_array *, struct _jc_object *);
extern void _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$method$doAnalysis$aa9bebddf0f94464(_jc_env *, struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$object *);
extern jboolean _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$method$isForward$48ad1d1fce741d09(_jc_env *, struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$method_info$accumulateAfterFlowSets$d719cbc2c96a3105;
extern _jc_method _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$method_info$doAnalysis$aa9bebddf0f94464;
extern _jc_method _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$method_info$isForward$48ad1d1fce741d09;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$vmethods {
	void	(*accumulateAfterFlowSets$d719cbc2c96a3105)(_jc_env *, struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$object *, struct _jc_object *, struct _jc_object_array *, struct _jc_object *);
	void	(*doAnalysis$aa9bebddf0f94464)(_jc_env *, struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$object *);
	jboolean	(*isForward$48ad1d1fce741d09)(_jc_env *, struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$object *);
};

// Vtable
struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_AbstractFlowAnalysis$vmethods	soot_toolkits_scalar_AbstractFlowAnalysis;
	_jc_soot_toolkits_scalar_BranchedFlowAnalysis$vmethods	soot_toolkits_scalar_BranchedFlowAnalysis;
	_jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$vmethods	soot_toolkits_scalar_ForwardBranchedFlowAnalysis;
};

// Vtype
struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$refs {
    _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$sub_refs	soot_toolkits_scalar_ForwardBranchedFlowAnalysis;
    _jc_soot_toolkits_scalar_BranchedFlowAnalysis$sub_refs	soot_toolkits_scalar_BranchedFlowAnalysis;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_refs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_soot_toolkits_scalar_BranchedFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_BranchedFlowAnalysis;
    _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_ForwardBranchedFlowAnalysis;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$object {
	_jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$vtype	*vtype;
	_jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$vtype _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_ForwardBranchedFlowAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$class_object;

#endif	/* _JC_soot_toolkits_scalar_ForwardBranchedFlowAnalysis_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/scalar/ForwardBranchedFlowAnalysis.h <==
// public abstract class soot.toolkits.scalar.ForwardBranchedFlowAnalysis

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 36c7c662bc399f02 soot_toolkits_scalar_AbstractFlowAnalysis
// @dep_class 6279fcb5fd9bedca soot_toolkits_scalar_BranchedFlowAnalysis
// @dep_class 1296f6ac3f04ebc9 soot_toolkits_scalar_ForwardBranchedFlowAnalysis

// header file dependencies
// @dep_header soot_toolkits_scalar_BranchedFlowAnalysis

#include "soot/toolkits/scalar/BranchedFlowAnalysis.h"

#ifndef _JC_soot_toolkits_scalar_ForwardBranchedFlowAnalysis_H_
#define _JC_soot_toolkits_scalar_ForwardBranchedFlowAnalysis_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_soot_Unit$object;
struct _jc_soot_toolkits_graph_UnitGraph$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$sub_refs	_jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$sub_refs;
typedef struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$sub_nonrefs	_jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$refs	_jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$refs;
typedef struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$nonrefs	_jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$nonrefs;
typedef struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$object	_jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$object;

typedef const struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$vmethods	_jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$vmethods;
typedef const struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$vtable	_jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$vtable;
typedef const struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$vtype	_jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$method$_init$4a1d314cee6c2507(_jc_env *, struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$object *, struct _jc_soot_toolkits_graph_UnitGraph$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$method$accumulateAfterFlowSets$d719cbc2c96a3105(_jc_env *, struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$object *, struct _jc_object *, struct _jc_object_array *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$method$doAnalysis$aa9bebddf0f94464(_jc_env *, struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$method$isForward$48ad1d1fce741d09(_jc_env *, struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$method_info$accumulateAfterFlowSets$d719cbc2c96a3105;
extern _jc_method _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$method_info$doAnalysis$aa9bebddf0f94464;
extern _jc_method _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$method_info$isForward$48ad1d1fce741d09;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$vmethods {
	void	(*accumulateAfterFlowSets$d719cbc2c96a3105)(_jc_env *, struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$object *, struct _jc_object *, struct _jc_object_array *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*doAnalysis$aa9bebddf0f94464)(_jc_env *, struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$object *) _JC_JCNI_ATTR;
	jboolean	(*isForward$48ad1d1fce741d09)(_jc_env *, struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_AbstractFlowAnalysis$vmethods	soot_toolkits_scalar_AbstractFlowAnalysis;
	_jc_soot_toolkits_scalar_BranchedFlowAnalysis$vmethods	soot_toolkits_scalar_BranchedFlowAnalysis;
	_jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$vmethods	soot_toolkits_scalar_ForwardBranchedFlowAnalysis;
};

// Vtype
struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$refs {
    _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$sub_refs	soot_toolkits_scalar_ForwardBranchedFlowAnalysis;
    _jc_soot_toolkits_scalar_BranchedFlowAnalysis$sub_refs	soot_toolkits_scalar_BranchedFlowAnalysis;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_refs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_soot_toolkits_scalar_BranchedFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_BranchedFlowAnalysis;
    _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_ForwardBranchedFlowAnalysis;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$object {
	_jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$vtype	*vtype;
	_jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$vtype _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_ForwardBranchedFlowAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$class_object;

#endif	/* _JC_soot_toolkits_scalar_ForwardBranchedFlowAnalysis_H_ */
